@@ -6,7 +6,7 @@ from supersetpdfreport.logging import logger
 import glob
 
 
-@celery_app.task(name="reports-pdf-scheduler")
+@celery_app.task(name="reports.pdf-scheduler")
 def reports_pdf_scheduler() -> None:
 
     logger.info("superset_pdf_report started")
